@@ -225,6 +225,8 @@ is_top_level <- function(arg_env, ...) {
     any(vapply(top_level_envs, identical, x = arg_env, FUN.VALUE = logical(1L)))
 }
 
+null_function <- local(function() NULL, baseenv())
+
 parser_hooks <- list(
     "{" = function(expr, action) {
         action$parse(as.list(expr)[-1L])
@@ -362,7 +364,9 @@ parse_expr <- function(content, expr, env, srcref = attr(expr, "srcref")) {
 
                     if (type == "function") {
                         env$functs <- c(env$functs, symbol)
-                        env$formals[[symbol]] <- value[[2L]]
+                        fun <- null_function
+                        formals(fun) <- value[[2L]]
+                        env$functions[[symbol]] <- fun
                         env$signatures[[symbol]] <- get_signature(symbol, value)
                     } else {
                         env$nonfuncts <- c(env$nonfuncts, symbol)
@@ -408,7 +412,7 @@ parse_document <- function(uri, content) {
             env$packages <- character()
             env$nonfuncts <- character()
             env$functs <- character()
-            env$formals <- list()
+            env$functions <- list()
             env$signatures <- list()
             env$definitions <- list()
             env$documentation <- list()
