@@ -3,7 +3,11 @@
 
 LanguageBase <- R6::R6Class("LanguageBase",
     private = list(
-        ticket = 0
+        ticket = 0,
+
+        finalize = function() {
+            self$request_callbacks$clear()
+        }
     ),
     public = list(
         catch_callback_error = TRUE,
@@ -16,10 +20,6 @@ LanguageBase <- R6::R6Class("LanguageBase",
             self$request_callbacks <- collections::dict()
         },
 
-        finalize = function() {
-            self$request_callbacks$clear()
-        },
-
         get_ticket = function() {
             private$ticket <- private$ticket + 1
             private$ticket
@@ -158,7 +158,6 @@ LanguageBase <- R6::R6Class("LanguageBase",
         },
 
         handle_notification = function(notification) {
-            logger$info("receive notification: ", notification)
             method <- notification$method
             params <- notification$params
             if (method %in% names(self$notification_handlers)) {
